/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.runtime;

import org.ow2.bonita.facade.uuid.ProcessInstanceUUID;
import org.ow2.bonita.util.Misc;


public class ActivityInstanceKey {

  protected ProcessInstanceUUID instanceUUID;
  protected String activityName;
  protected long dbid;

  protected ActivityInstanceKey() { }

  public ActivityInstanceKey(ProcessInstanceUUID instanceUUID, String activityName) {
    super();
    Misc.badStateIfNull(instanceUUID, "Cannot build a new ActivityInstanceKey from null processUUID");
    Misc.badStateIfNull(activityName, "Cannot build a new ActivityInstanceKey from null activityId");

    this.instanceUUID = instanceUUID;
    this.activityName = activityName;
  }
  @Override
  public boolean equals(Object obj) {
    if (obj == null) {
      return false;
    }
    if (!(obj instanceof ActivityInstanceKey)) {
      return false;
    }
    ActivityInstanceKey other = (ActivityInstanceKey) obj;

    return other.instanceUUID.equals(instanceUUID) && other.activityName.equals(activityName);
  }

  @Override
  public int hashCode() {
    return this.instanceUUID.hashCode() + 7 * this.activityName.hashCode();
  }

  public long getNumber() {
    return dbid;
  }
}


